Combine multi-dimensional arrays with lists
Arguments
- ...
any number of lists with dimensions or a single list of list arrrays
- rev.along
dimension to reverse before binding (passed to
abind)
Combine multi-dimensional arrays with lists
any number of lists with dimensions or a single list of list arrrays
dimension to reverse before binding (passed to abind)