Make a multiplet matrix with weights and scalar coupling coefficients
Source:R/resonance.R
make_coupling_mat.RdMake a multiplet matrix with weights and scalar coupling coefficients
R/resonance.R
make_coupling_mat.RdMake a multiplet matrix with weights and scalar coupling coefficients